==> dna-0.2.2.tar.gz: example/sdl.dart <==
// Copyright (c) 2016, root.ext@gmail.com. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

import '../lib/dna.dart';

const int SDL_INIT_TIMER = 0x00000001;
const int SDL_INIT_AUDIO =  0x00000010;
const int SDL_INIT_VIDEO = 0x00000020;  /**< SDL_INIT_VIDEO implies SDL_INIT_EVENTS */
const int SDL_INIT_JOYSTICK = 0x00000200;  /**< SDL_INIT_JOYSTICK implies SDL_INIT_EVENTS */
const int SDL_INIT_HAPTIC = 0x00001000;
const int SDL_INIT_GAMECONTROLLER = 0x00002000;  /**< SDL_INIT_GAMECONTROLLER implies SDL_INIT_JOYSTICK */
const int SDL_INIT_EVENTS = 0x00004000;
const int SDL_INIT_NOPARACHUTE = 0x00100000;  /**< Don't catch fatal signals */
const int SDL_INIT_EVERYTHING  = SDL_INIT_TIMER | SDL_INIT_AUDIO | SDL_INIT_VIDEO | SDL_INIT_EVENTS |
  SDL_INIT_JOYSTICK | SDL_INIT_HAPTIC | SDL_INIT_GAMECONTROLLER;

const int SDL_WINDOW_FULLSCREEN = 0x00000001;         /**< fullscreen window */
const int SDL_WINDOW_OPENGL = 0x00000002;             /**< window usable with OpenGL context */
const int SDL_WINDOW_SHOWN = 0x00000004;              /**< window is visible */
const int SDL_WINDOW_HIDDEN = 0x00000008;             /**< window is not visible */
const int SDL_WINDOW_BORDERLESS = 0x00000010;         /**< no window decoration */
const int SDL_WINDOW_RESIZABLE = 0x00000020;          /**< window can be resized */
const int SDL_WINDOW_MINIMIZED = 0x00000040;          /**< window is minimized */
const int SDL_WINDOW_MAXIMIZED = 0x00000080;          /**< window is maximized */
const int SDL_WINDOW_INPUT_GRABBED = 0x00000100;      /**< window has grabbed input focus */
const int SDL_WINDOW_INPUT_FOCUS = 0x00000200;        /**< window has input focus */
const int SDL_WINDOW_MOUSE_FOCUS = 0x00000400;        /**< window has mouse focus */
const int SDL_WINDOW_FULLSCREEN_DESKTOP = ( SDL_WINDOW_FULLSCREEN | 0x00001000 );
const int SDL_WINDOW_FOREIGN = 0x00000800;            /**< window not created by SDL */

const int SDL_GL_RED_SIZE = 0x00000000;
const int SDL_GL_GREEN_SIZE = 0x00000001;
const int SDL_GL_BLUE_SIZE = 0x00000002;
const int SDL_GL_ALPHA_SIZE = 0x00000003;
const int SDL_GL_BUFFER_SIZE = 0x00000004;
const int SDL_GL_DOUBLEBUFFER = 0x00000005;
const int SDL_GL_DEPTH_SIZE = 0x00000006;
const int SDL_GL_STENCIL_SIZE = 0x00000007;
const int SDL_GL_ACCUM_RED_SIZE = 0x00000008;
const int SDL_GL_ACCUM_GREEN_SIZE = 0x00000009;
const int SDL_GL_ACCUM_BLUE_SIZE = 0x0000000A;
const int SDL_GL_ACCUM_ALPHA_SIZE = 0x0000000B;
const int SDL_GL_STEREO = 0x0000000C;
const int SDL_GL_MULTISAMPLEBUFFERS = 0x0000000D;
const int SDL_GL_MULTISAMPLESAMPLES = 0x0000000E;
const int SDL_GL_ACCELERATED_VISUAL = 0x0000000F;
const int SDL_GL_RETAINED_BACKING = 0x00000010;
const int SDL_GL_CONTEXT_MAJOR_VERSION = 0x00000011;
const int SDL_GL_CONTEXT_MINOR_VERSION = 0x00000012;
const int SDL_GL_CONTEXT_EGL = 0x00000013;
const int SDL_GL_CONTEXT_FLAGS = 0x00000014;
const int SDL_GL_CONTEXT_PROFILE_MASK = 0x00000015;
const int SDL_GL_SHARE_WITH_CURRENT_CONTEXT = 0x00000016;

@Library('libSDL2.so', 'SDL2.dll')
class Sdl {
  dynamic lib = new DynamicLibrary<Sdl>();

  int SDL_Init(int flags) { return lib.SDL_Init(flags); }
  int SDL_InitSubSystem(int flags) { return lib.SDL_InitSubSystem(flags); }
  void SDL_QuitSubSystem(int flags) { return lib.SDL_QuitSubSystem(flags); }
  int SDL_WasInit(int flags) { return lib.SDL_WasInit(flags); }
  void SDL_Quit() { return lib.SDL_Quit(); }

  @Method(C_POINTER) int SDL_CreateWindow(@Param(C_STRING) String title, int x, int y, int w, int h, int flags) { return lib.SDL_CreateWindow(title, x, y, w, h, flags); }
  void SDL_ShowWindow(@Param(C_POINTER)int window) { return lib.SDL_ShowWindow(window); }
  void SDL_DestroyWindow(@Param(C_POINTER) int window) { return lib.SDL_DestroyWindow(window); }
  void SDL_HideWindow(@Param(C_POINTER)int window) { return lib.SDL_HideWindow(window); }
  void SDL_RaiseWindow(@Param(C_POINTER)int window) { return lib.SDL_RaiseWindow(window); }
  void SDL_MaximizeWindow(@Param(C_POINTER)int window) { return lib.SDL_MaximizeWindow(window); }
  void SDL_MinimizeWindow(@Param(C_POINTER)int window) { return lib.SDL_MinimizeWindow(window); }
  void SDL_RestoreWindow(@Param(C_POINTER)int window) { return lib.SDL_RestoreWindow(window); }
  int SDL_SetWindowFullscreen(@Param(C_POINTER)int window, int flags) { return lib.SDL_SetWindowFullscreen(window, flags); }

  int SDL_PollEvent(@Param(C_STRUCT) @Out() Ref<SDL_Event> e) { return lib.SDL_PollEvent(e); }


  @Method(C_POINTER) SDL_GL_CreateContext(@Param(C_POINTER) window) { return lib.SDL_GL_CreateContext(window); }
  void SDL_GL_DeleteContext(@Param(C_POINTER) context) { return lib.SDL_GL_DeleteContext(context); }
  void SDL_GL_MakeCurrent(@Param(C_POINTER) window, @Param(C_POINTER) context) { return lib.SDL_GL_MakeCurrent(window, context); }
  @Method(C_POINTER) SDL_GL_GetCurrentContext() { return lib.SDL_GL_GetCurrentContext(); }
  @Method(C_POINTER) SDL_GL_GetCurrentWindow() { return lib.SDL_GL_GetCurrentWindow(); }
  void SDL_GL_SwapWindow(@Param(C_POINTER) window) { return lib.SDL_GL_SwapWindow(window); }
  void SDL_GL_SetSwapInterval(int value) { return lib.SDL_GL_SetSwapInterval(value); }
  int SDL_GL_GetSwapInterval() { return lib.SDL_GL_GetSwapInterval(); }
  void SDL_GL_SetAttribute(int attr, int value) { return lib.SDL_GL_SetAttribute(attr, value); }
}

@Struct()
class SDL_Event {
  @Field(C_INT)
  int type;

  @Field(C_INT) int pad1;
  @Field(C_INT) int pad2;
  @Field(C_INT) int pad3;
  @Field(C_INT) int pad4;
  @Field(C_INT) int pad5;
  @Field(C_INT) int pad6;
  @Field(C_INT) int pad7;
  @Field(C_INT) int pad8;
  @Field(C_INT) int pad9;
  @Field(C_INT) int pad0;
}

==> dna-0.4.0.tar.gz: example/sdl.dart <==
//  Copyright 2016 root.ext@gmail.com
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

import '../lib/dna.dart';

const int SDL_INIT_TIMER = 0x00000001;
const int SDL_INIT_AUDIO =  0x00000010;
const int SDL_INIT_VIDEO = 0x00000020;  /**< SDL_INIT_VIDEO implies SDL_INIT_EVENTS */
const int SDL_INIT_JOYSTICK = 0x00000200;  /**< SDL_INIT_JOYSTICK implies SDL_INIT_EVENTS */
const int SDL_INIT_HAPTIC = 0x00001000;
const int SDL_INIT_GAMECONTROLLER = 0x00002000;  /**< SDL_INIT_GAMECONTROLLER implies SDL_INIT_JOYSTICK */
const int SDL_INIT_EVENTS = 0x00004000;
const int SDL_INIT_NOPARACHUTE = 0x00100000;  /**< Don't catch fatal signals */
const int SDL_INIT_EVERYTHING  = SDL_INIT_TIMER | SDL_INIT_AUDIO | SDL_INIT_VIDEO | SDL_INIT_EVENTS |
  SDL_INIT_JOYSTICK | SDL_INIT_HAPTIC | SDL_INIT_GAMECONTROLLER;

const int SDL_WINDOW_FULLSCREEN = 0x00000001;         /**< fullscreen window */
const int SDL_WINDOW_OPENGL = 0x00000002;             /**< window usable with OpenGL context */
const int SDL_WINDOW_SHOWN = 0x00000004;              /**< window is visible */
const int SDL_WINDOW_HIDDEN = 0x00000008;             /**< window is not visible */
const int SDL_WINDOW_BORDERLESS = 0x00000010;         /**< no window decoration */
const int SDL_WINDOW_RESIZABLE = 0x00000020;          /**< window can be resized */
const int SDL_WINDOW_MINIMIZED = 0x00000040;          /**< window is minimized */
const int SDL_WINDOW_MAXIMIZED = 0x00000080;          /**< window is maximized */
const int SDL_WINDOW_INPUT_GRABBED = 0x00000100;      /**< window has grabbed input focus */
const int SDL_WINDOW_INPUT_FOCUS = 0x00000200;        /**< window has input focus */
const int SDL_WINDOW_MOUSE_FOCUS = 0x00000400;        /**< window has mouse focus */
const int SDL_WINDOW_FULLSCREEN_DESKTOP = ( SDL_WINDOW_FULLSCREEN | 0x00001000 );
const int SDL_WINDOW_FOREIGN = 0x00000800;            /**< window not created by SDL */

const int SDL_GL_RED_SIZE = 0x00000000;
const int SDL_GL_GREEN_SIZE = 0x00000001;
const int SDL_GL_BLUE_SIZE = 0x00000002;
const int SDL_GL_ALPHA_SIZE = 0x00000003;
const int SDL_GL_BUFFER_SIZE = 0x00000004;
const int SDL_GL_DOUBLEBUFFER = 0x00000005;
const int SDL_GL_DEPTH_SIZE = 0x00000006;
const int SDL_GL_STENCIL_SIZE = 0x00000007;
const int SDL_GL_ACCUM_RED_SIZE = 0x00000008;
const int SDL_GL_ACCUM_GREEN_SIZE = 0x00000009;
const int SDL_GL_ACCUM_BLUE_SIZE = 0x0000000A;
const int SDL_GL_ACCUM_ALPHA_SIZE = 0x0000000B;
const int SDL_GL_STEREO = 0x0000000C;
const int SDL_GL_MULTISAMPLEBUFFERS = 0x0000000D;
const int SDL_GL_MULTISAMPLESAMPLES = 0x0000000E;
const int SDL_GL_ACCELERATED_VISUAL = 0x0000000F;
const int SDL_GL_RETAINED_BACKING = 0x00000010;
const int SDL_GL_CONTEXT_MAJOR_VERSION = 0x00000011;
const int SDL_GL_CONTEXT_MINOR_VERSION = 0x00000012;
const int SDL_GL_CONTEXT_EGL = 0x00000013;
const int SDL_GL_CONTEXT_FLAGS = 0x00000014;
const int SDL_GL_CONTEXT_PROFILE_MASK = 0x00000015;
const int SDL_GL_SHARE_WITH_CURRENT_CONTEXT = 0x00000016;

@Library('libSDL2.so', 'SDL2.dll')
class Sdl {
  dynamic lib = new DynamicLibrary<Sdl>();

  int SDL_Init(int flags) { return lib.SDL_Init(flags); }
  int SDL_InitSubSystem(int flags) { return lib.SDL_InitSubSystem(flags); }
  void SDL_QuitSubSystem(int flags) { return lib.SDL_QuitSubSystem(flags); }
  int SDL_WasInit(int flags) { return lib.SDL_WasInit(flags); }
  void SDL_Quit() { return lib.SDL_Quit(); }

  @Method(C_POINTER) int SDL_CreateWindow(@Param(C_STRING) String title, int x, int y, int w, int h, int flags) { return lib.SDL_CreateWindow(title, x, y, w, h, flags); }
  void SDL_ShowWindow(@Param(C_POINTER)int window) { return lib.SDL_ShowWindow(window); }
  void SDL_DestroyWindow(@Param(C_POINTER) int window) { return lib.SDL_DestroyWindow(window); }
  void SDL_HideWindow(@Param(C_POINTER)int window) { return lib.SDL_HideWindow(window); }
  void SDL_RaiseWindow(@Param(C_POINTER)int window) { return lib.SDL_RaiseWindow(window); }
  void SDL_MaximizeWindow(@Param(C_POINTER)int window) { return lib.SDL_MaximizeWindow(window); }
  void SDL_MinimizeWindow(@Param(C_POINTER)int window) { return lib.SDL_MinimizeWindow(window); }
  void SDL_RestoreWindow(@Param(C_POINTER)int window) { return lib.SDL_RestoreWindow(window); }
  int SDL_SetWindowFullscreen(@Param(C_POINTER)int window, int flags) { return lib.SDL_SetWindowFullscreen(window, flags); }

  int SDL_PollEvent(@Param(C_STRUCT, out: true) Ref<SDL_Event> e) { return lib.SDL_PollEvent(e); }


  @Method(C_POINTER) SDL_GL_CreateContext(@Param(C_POINTER) window) { return lib.SDL_GL_CreateContext(window); }
  void SDL_GL_DeleteContext(@Param(C_POINTER) context) { return lib.SDL_GL_DeleteContext(context); }
  void SDL_GL_MakeCurrent(@Param(C_POINTER) window, @Param(C_POINTER) context) { return lib.SDL_GL_MakeCurrent(window, context); }
  @Method(C_POINTER) SDL_GL_GetCurrentContext() { return lib.SDL_GL_GetCurrentContext(); }
  @Method(C_POINTER) SDL_GL_GetCurrentWindow() { return lib.SDL_GL_GetCurrentWindow(); }
  void SDL_GL_SwapWindow(@Param(C_POINTER) window) { return lib.SDL_GL_SwapWindow(window); }
  void SDL_GL_SetSwapInterval(int value) { return lib.SDL_GL_SetSwapInterval(value); }
  int SDL_GL_GetSwapInterval() { return lib.SDL_GL_GetSwapInterval(); }
  void SDL_GL_SetAttribute(int attr, int value) { return lib.SDL_GL_SetAttribute(attr, value); }
}

@Struct()
class SDL_Event {
  @Field(C_INT)
  int type;

  @Field(C_INT) int pad1;
  @Field(C_INT) int pad2;
  @Field(C_INT) int pad3;
  @Field(C_INT) int pad4;
  @Field(C_INT) int pad5;
  @Field(C_INT) int pad6;
  @Field(C_INT) int pad7;
  @Field(C_INT) int pad8;
  @Field(C_INT) int pad9;
  @Field(C_INT) int pad0;
}
